@@ -11,6 +11,7 @@ from typing import BinaryIO
 from typing import Callable
 from typing import Literal
 from typing import TextIO
+from typing import TypeVar
 from typing import overload
 from urllib.parse import SplitResult
 
@@ -40,6 +41,28 @@ __all__ = [
     "ProxyUPath",
 ]
 
+T = TypeVar("T")
+
+
+class classmethod_or_method(classmethod):
+    """A decorator that can be used as a classmethod or an instance method.
+
+    When called on the class, it behaves like a classmethod.
+    When called on an instance, it behaves like an instance method.
+
+    """
+
+    def __get__(
+        self,
+        instance: T | None,
+        owner: type[T] | None = None,
+        /,
+    ) -> Callable[..., T]:
+        if instance is None:
+            return self.__func__.__get__(owner)
+        else:
+            return self.__func__.__get__(instance)
+
 
 class ProxyUPath:
     """ProxyUPath base class
@@ -380,9 +403,12 @@ class ProxyUPath:
     def samefile(self, other_path) -> bool:
         return self.__wrapped__.samefile(other_path)
 
-    @classmethod
-    def cwd(cls) -> Self:
-        raise UnsupportedOperation(".cwd() not supported")
+    @classmethod_or_method
+    def cwd(cls_or_self) -> Self:  # noqa: B902
+        if isinstance(cls_or_self, type):
+            raise UnsupportedOperation(".cwd() not supported")
+        else:
+            return cls_or_self._from_upath(cls_or_self.__wrapped__.cwd())
 
     @classmethod
     def home(cls) -> Self:
